@@ -6,7 +6,6 @@ from ._dump_app import DumpApp
 from ._landing_app import LandingApp
 from ._migrate_app import MigrateApp
 from ._modules_app import ModulesApp
-from ._populate_app import PopulateApp
 from ._profile_app import ProfileApp
 from ._purge import PurgeApp
 from ._repo_app import RepoApp
@@ -22,7 +21,6 @@ __all__ = [
     "LandingApp",
     "MigrateApp",
     "ModulesApp",
-    "PopulateApp",
     "ProfileApp",
     "PurgeApp",
     "RepoApp",
