@@ -78,9 +78,6 @@ def test_deploy_complete_org(env_vars: EnvironmentVariables, build_dir: Path) ->
 @pytest.mark.skipif(
     sys.version_info < (3, 11), reason="We only run this test on Python 3.11+ to avoid parallelism issues"
 )
-@pytest.mark.skip(
-    "We are currently changing the MigrationModel and that is causing the ResourceViewMapping do fail until that is deployed"
-)
 def test_deploy_complete_org_alpha(env_vars: EnvironmentVariables, build_dir: Path) -> None:
     build = BuildCommand(silent=True, skip_tracking=True)
 
