@@ -1,8 +1,6 @@
-import pytest
 from cognite.client.data_classes import Function
 
 from cognite_toolkit._cdf_tk.client import ToolkitClient
-from cognite_toolkit._cdf_tk.exceptions import ResourceRetrievalError
 
 
 class TestLookupFunctionsIds:
@@ -22,10 +20,9 @@ class TestLookupFunctionsIds:
         assert result is None
 
     def test_lookup_functions_id_not_found_raise(self, toolkit_client: ToolkitClient) -> None:
-        with pytest.raises(ResourceRetrievalError) as e:
-            _ = toolkit_client.lookup.functions.id("non_existent_function")
+        result = toolkit_client.lookup.functions.id("non_existent_function")
 
-        assert "Failed to retrieve Function with external_id ['non_existent_function']" in str(e.value)
+        assert result is None
 
     def test_lookup_functions_id_not_found(self, toolkit_client: ToolkitClient) -> None:
         result = toolkit_client.lookup.functions.id("", allow_empty=True)
