@@ -2,8 +2,8 @@ from __future__ import annotations
 
 from cognite_toolkit._cdf_tk.cdf_toml import CDFToml
 from cognite_toolkit._cdf_tk.commands import BuildCommand
+from cognite_toolkit._cdf_tk.cruds import CRUDS_BY_FOLDER_NAME
 from cognite_toolkit._cdf_tk.data_classes import BuildConfigYAML
-from cognite_toolkit._cdf_tk.loaders import LOADER_BY_FOLDER_NAME
 from cognite_toolkit._cdf_tk.utils import iterate_modules
 from tests.data import PROJECT_FOR_TEST
 from tests.test_unit.test_cdf_tk.constants import BUILD_DIR
@@ -24,6 +24,6 @@ class TestBuildConfigYAML:
         # The resulting build folder should only have subfolders that are matching the folder name
         # used by the loaders.
         invalid_resource_folders = [
-            dir_.name for dir_ in BUILD_DIR.iterdir() if dir_.is_dir() and dir_.name not in LOADER_BY_FOLDER_NAME
+            dir_.name for dir_ in BUILD_DIR.iterdir() if dir_.is_dir() and dir_.name not in CRUDS_BY_FOLDER_NAME
         ]
         assert not invalid_resource_folders, f"Invalid resource folders after build: {invalid_resource_folders}"
